@@ -32,12 +32,12 @@ public:
 
   virtual Gnome::Gda::Value get_primary_key_value(const Gtk::TreeModel::iterator& row);
   virtual Gnome::Gda::Value get_primary_key_value_selected();
-  
-  virtual Gnome::Gda::Value get_entered_field_data(const Field& field) const;
-  virtual void set_entered_field_data(const Field& field, const Gnome::Gda::Value& value);
-  
+
+  virtual Gnome::Gda::Value get_entered_field_data(const LayoutItem_Field& field) const;
+  virtual void set_entered_field_data(const LayoutItem_Field& field, const Gnome::Gda::Value& value);
+
   virtual guint get_records_count() const;
-    
+
   //Primary Key value:
   typedef sigc::signal<void, Gnome::Gda::Value> type_signal_user_requested_details;
   type_signal_user_requested_details signal_user_requested_details();
@@ -53,7 +53,11 @@ protected:
   virtual void fill_from_database(); //override.
   virtual void fill_column_titles();
 
-  void do_lookups(const Gtk::TreeModel::iterator& row, const Field& field_changed, const Gnome::Gda::Value& field_value, const Field& primary_key, const Gnome::Gda::Value& primary_key_value);
+  virtual bool get_field_primary_key_index(guint& field_column) const; //TODO: visible 
+  virtual bool get_field_primary_key(Field& field) const;
+
+  void do_lookups(const Gtk::TreeModel::iterator& row, const LayoutItem_Field& field_changed, const Gnome::Gda::Value& field_value, const Field& primary_key, const Gnome::Gda::Value& primary_key_value);
+  void refresh_related_fields(const Gtk::TreeModel::iterator& row, const LayoutItem_Field& field_changed, const Gnome::Gda::Value& field_value, const Field& primary_key, const Gnome::Gda::Value& primary_key_value);
 
   //Signal handlers:
   virtual void on_adddel_user_requested_add();
@@ -62,12 +66,16 @@ protected:
   virtual void on_adddel_user_added(const Gtk::TreeModel::iterator& row);
   virtual void on_adddel_user_reordered_columns();
 
+  virtual void on_adddel_user_requested_layout();
+
   virtual void on_adddel_user_changed(const Gtk::TreeModel::iterator& row, guint col);
 
   virtual void on_record_added(const Gnome::Gda::Value& primary_key_value); //Not a signal handler. To be overridden.
 
   virtual bool get_field_column_index(const Glib::ustring& field_name, guint& index) const;
-  
+
+  virtual void print_layout_group(xmlpp::Element* node_parent, const LayoutGroup& group);
+
   //Member widgers:
   mutable DbAddDel_WithButtons m_AddDel; //mutable because its get_ methods aren't const.
 
