@@ -19,15 +19,15 @@
  */
 
 #include "notebook_data.h"
-#include <libintl.h>
+#include <glibmm/i18n.h>
 
 Notebook_Data::Notebook_Data()
 {
   //Add Pages:
-  pages().push_back(Gtk::Notebook_Helpers::TabElem(m_Box_List, gettext("List")));
+  pages().push_back(Gtk::Notebook_Helpers::TabElem(m_Box_List, _("List")));
   m_iPage_List = 0;
 
-  pages().push_back(Gtk::Notebook_Helpers::TabElem(m_Box_Details, gettext("Details")));
+  pages().push_back(Gtk::Notebook_Helpers::TabElem(m_Box_Details, _("Details")));
   m_iPage_Details = 1;
 
 
@@ -37,7 +37,7 @@ Notebook_Data::Notebook_Data()
   m_Box_List.signal_user_requested_details().connect(sigc::mem_fun(*this, &Notebook_Data::on_Details_user_requested_details));
 
   //Allow Details's Related Records to ask Details to show a record.
-  m_Box_Details.signal_user_requested_related_details().connect(sigc::mem_fun(*this, &Notebook_Data::on_Details_user_requested_related_details));
+  //m_Box_Details.signal_user_requested_related_details().connect(sigc::mem_fun(*this, &Notebook_Data::on_Details_user_requested_related_details));
 
     
   //Allow Details to ask List to ask Details to show a different record:
@@ -60,12 +60,18 @@ Notebook_Data::~Notebook_Data()
 {
 }
 
-void Notebook_Data::init_db_details(const Glib::ustring& strDatabaseName, const Glib::ustring& strTableName, const Glib::ustring& strWhereClause)
+void Notebook_Data::init_db_details(const Glib::ustring& strTableName, const Glib::ustring& strWhereClause)
 {
   //strWhereClause is only used as a result of a find.
 
-  m_Box_List.init_db_details(strDatabaseName, strTableName, strWhereClause);
-  m_Box_Details.init_db_details(strDatabaseName, strTableName, m_Box_List.get_primary_key_value_selected());
+  //Performance optimisation:
+  //Keep the connection open during all these operations:
+  {
+    sharedptr<SharedConnection> sharedconnection = connect_to_server();
+  
+    m_Box_List.init_db_details(strTableName, strWhereClause);
+    m_Box_Details.init_db_details(strTableName, m_Box_List.get_primary_key_value_selected());
+  }
 
   //Select List as default:
   set_current_page(m_iPage_List);
@@ -73,14 +79,14 @@ void Notebook_Data::init_db_details(const Glib::ustring& strDatabaseName, const
 
 void Notebook_Data::on_Details_user_requested_details(Gnome::Gda::Value primary_key_value)
 {
-  m_Box_Details.init_db_details(primary_key_value); //Uses existing connection, database, and table.
+  m_Box_Details.refresh_db_details(primary_key_value);
   set_current_page(m_iPage_Details);
 }
 
 void Notebook_Data::on_Details_user_requested_related_details(Glib::ustring strTableName, Gnome::Gda::Value primary_key_value)
 {
   //Show a different table:
-  init_db_details(m_Box_Details.get_database_name(), strTableName);
+  init_db_details(strTableName);
 
   //Show the specific record:
   on_Details_user_requested_details(primary_key_value);
@@ -111,6 +117,19 @@ void Notebook_Data::do_menu_developer_layout()
   } 
 }
 
+void Notebook_Data::do_menu_file_print()
+{
+  int iPageCurrent = get_current_page();
+
+  Gtk::Widget* pChild  = get_nth_page(iPageCurrent);
+  if(pChild)
+  {
+    Box_Data* pBox = dynamic_cast<Box_Data*>(pChild);
+    if(pBox)
+      pBox->print_layout();
+  } 
+}
+
 enum dataview
 {
   DATA_VIEW_Details,
