@@ -22,7 +22,7 @@
 #include "../box_db_table.h"
 //#include <libgnome/gnome-i18n.h>
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
-#include <libintl.h>
+#include <glibmm/i18n.h>
 
 
 Dialog_Relationships::Dialog_Relationships(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
@@ -31,7 +31,7 @@ Dialog_Relationships::Dialog_Relationships(BaseObjectType* cobject, const Glib::
 {
   refGlade->get_widget_derived("vbox_placeholder", m_box);
 
-  m_label_frame->set_text( Bakery::App_Gtk::util_bold_message(gettext("Relationships")) );
+  m_label_frame->set_text( Bakery::App_Gtk::util_bold_message(_("Relationships")) );
   m_label_frame->set_use_markup();
 
   //Fill composite view:
