@@ -23,6 +23,7 @@
 #include "../data_structure/glomconversions.h"
 #include "../application.h"
 #include "../mode_data/dialog_choose_field.h"
+#include <glibmm/i18n.h>
 
 /*
 DataWidget::DataWidget(Field::glom_field_type glom_type, const Glib::ustring& title)
@@ -232,19 +233,19 @@ void DataWidget::setup_menu()
 
   m_refActionGroup->add(Gtk::Action::create("ContextMenu", "Context Menu") );
 
-  m_refContextLayout =  Gtk::Action::create("ContextLayout", gettext("Choose Field"));
+  m_refContextLayout =  Gtk::Action::create("ContextLayout", _("Choose Field"));
   m_refActionGroup->add(m_refContextLayout,
     sigc::mem_fun(*this, &DataWidget::on_menupopup_activate_layout) );
 
-  m_refContextAddField =  Gtk::Action::create("ContextAddField", gettext("Add Field"));
+  m_refContextAddField =  Gtk::Action::create("ContextAddField", _("Add Field"));
   m_refActionGroup->add(m_refContextAddField,
     sigc::bind( sigc::mem_fun(*this, &DataWidget::on_menupopup_add_item), TreeStore_Layout::TYPE_FIELD ) );
 
-  m_refContextAddRelatedRecords =  Gtk::Action::create("ContextAddRelatedRecords", gettext("Add Related Records"));
+  m_refContextAddRelatedRecords =  Gtk::Action::create("ContextAddRelatedRecords", _("Add Related Records"));
   m_refActionGroup->add(m_refContextAddRelatedRecords,
     sigc::bind( sigc::mem_fun(*this, &DataWidget::on_menupopup_add_item), TreeStore_Layout::TYPE_PORTAL ) );
 
-  m_refContextAddGroup =  Gtk::Action::create("ContextAddGroup", gettext("Add Group"));
+  m_refContextAddGroup =  Gtk::Action::create("ContextAddGroup", _("Add Group"));
   m_refActionGroup->add(m_refContextAddGroup,
     sigc::bind( sigc::mem_fun(*this, &DataWidget::on_menupopup_add_item), TreeStore_Layout::TYPE_GROUP ) );
 
