@@ -20,7 +20,7 @@
 
 #include "db_adddel.h"
 #include <algorithm> //For std::find.
-#include <libintl.h>
+#include <glibmm/i18n.h>
 #include "../adddel/cellrendererlist.h"
 #include "db_treeviewcolumn_glom.h"
 #include "../../data_structure/glomconversions.h"
@@ -58,7 +58,8 @@ DbAddDel::DbAddDel()
   m_pMenuPopup(0),
   m_auto_add(true),
   m_allow_add(true),
-  m_allow_delete(true)
+  m_allow_delete(true),
+  m_columns_ready(false)
 {
   set_prevent_user_signals();
   set_ignore_treeview_signals();
@@ -211,7 +212,7 @@ void DbAddDel::setup_menu()
     sigc::mem_fun(*this, &DbAddDel::on_MenuPopup_activate_Add) );
   m_refContextAdd->set_sensitive(m_allow_add);
 
-  m_refContextLayout =  Gtk::Action::create("ContextLayout", gettext("Layout"));
+  m_refContextLayout =  Gtk::Action::create("ContextLayout", _("Layout"));
   m_refActionGroup->add(m_refContextLayout,
     sigc::mem_fun(*this, &DbAddDel::on_MenuPopup_activate_layout) );
 
@@ -560,6 +561,8 @@ void DbAddDel::set_column_title(guint col, const Glib::ustring& strText)
 
 void DbAddDel::construct_specified_columns()
 {
+  InnerIgnore innerIgnore(this);
+
   //TODO_optimisation: This is called many times, just to simplify the API.
 
   //Delay actual use of set_column_*() stuff until this method is called.
@@ -603,14 +606,14 @@ void DbAddDel::construct_specified_columns()
 
       record.add( *pModelColumn );
 
-      fields.push_back(iter->m_field.m_field);
+      fields.push_back(iter->m_field);
 
       i++;
     }
   }
 
   //Create the model from the ColumnRecord:
-  m_refListStore = type_model_store::create(record, "TODO: table_name", fields);
+  m_refListStore = type_model_store::create(record, m_table_name, fields);
 
   m_TreeView.set_model(m_refListStore);
 
@@ -711,12 +714,12 @@ void DbAddDel::construct_specified_columns()
       }
 
     ++view_column_index;
-    
+ 
     } //is visible
 
     ++model_column_index;
   }
-  
+
   //Delete the vector's items:
   for(type_vecModelColumns::iterator iter = vecModelColumns.begin(); iter != vecModelColumns.end(); ++iter)
   {
@@ -770,6 +773,13 @@ void DbAddDel::set_value_selected(const LayoutItem_Field& layout_item, const Gno
 void DbAddDel::remove_all_columns()
 {
   m_ColumnTypes.clear();
+
+  m_columns_ready = false;
+}
+
+void DbAddDel::set_table_name(const Glib::ustring& table_name)
+{
+  m_table_name = table_name;
 }
 
 guint DbAddDel::add_column(const LayoutItem_Field& field)
@@ -790,7 +800,8 @@ guint DbAddDel::add_column(const LayoutItem_Field& field)
   m_ColumnTypes.push_back(column_info);
 
   //Generate appropriate model columns:
-  construct_specified_columns();
+  if(m_columns_ready)
+    construct_specified_columns();
 
   //Tell the View to use the model:
   //m_TreeView.set_model(m_refListStore);
@@ -798,6 +809,13 @@ guint DbAddDel::add_column(const LayoutItem_Field& field)
   return m_ColumnTypes.size() - 1;
 }
 
+
+void DbAddDel::set_columns_ready()
+{
+  m_columns_ready = true;
+  construct_specified_columns();
+}
+
 DbAddDel::type_list_indexes DbAddDel::get_column_index(const LayoutItem_Field& layout_item) const
 {
   //TODO_Performance: Replace all this looping by a cache/map:
@@ -862,7 +880,8 @@ void DbAddDel::set_column_choices(guint col, const type_vecStrings& vecStrings)
     else
     {
       //The column does not exist yet, so we must create it:
-      construct_specified_columns();
+      if(m_columns_ready)
+        construct_specified_columns();
     }
   }
 }
